@@ -11,6 +11,7 @@ __all__ = [
     'color_chain',
     'colorbytes',
     'get_ansi_type',
+    'is_vt_enabled',
     'randcolor',
     'rgb2ansi_escape',
 ]
@@ -18,6 +19,7 @@ __all__ = [
 import os
 import random
 import re
+import sys
 from collections import Counter
 from collections.abc import Buffer
 from copy import deepcopy
@@ -53,9 +55,9 @@ from .colorconv import (
 )
 from .._typing import AnsiColorAlias, ColorDictKeys, Int3Tuple
 
-os.system('')
+# os.system('')
 
-CSI: Final[bytes] = b'['
+CSI: Final[bytes] = b'\x1b['
 SGR_RESET: Final[bytes] = CSI + b'0m'
 SGR_RESET_S: Final[str] = SGR_RESET.decode()
 
@@ -149,7 +151,9 @@ _ANSI16C_I2KV = cast(
     dict[int, tuple[ColorDictKeys, Int3Tuple]],
     {
         v: (k, ansi_4bit_to_rgb(v))
-        for x in (zip(('fg', 'bg'), (j, j + 10)) for i in (30, 90) for j in range(i, i + 8))
+        for x in (
+            zip(('fg', 'bg'), (j, j + 10)) for i in (30, 90) for j in range(i, i + 8)
+        )
         for (k, v) in x
     },
 )
@@ -264,8 +268,6 @@ class colorbytes(bytes):
 class ansicolor4Bit(colorbytes):
     """ANSI 4-bit color format.
 
-    alias: '4b'
-
     Supports 16 colors:
         * 8 standard colors:
             {0: black, 1: red, 2: green, 3: yellow, 4: blue, 5: magenta, 6: cyan, 7: white}
@@ -296,8 +298,6 @@ class ansicolor4Bit(colorbytes):
 class ansicolor8Bit(colorbytes):
     """ANSI 8-Bit color format.
 
-    alias: '8b'
-
     Supports 256 colors, mapped to the following value ranges:
         * (0, 15): Corresponds to ANSI 4-bit colors.
         * (16, 231): Represents a 6x6x6 RGB color cube.
@@ -326,8 +326,6 @@ class ansicolor8Bit(colorbytes):
 class ansicolor24Bit(colorbytes):
     """ANSI 24-Bit color format.
 
-    alias: '24b'
-
     Supports all colors in the RGB color space (16,777,216 total).
 
     Color codes use escape sequences of the form:
@@ -350,52 +348,60 @@ class ansicolor24Bit(colorbytes):
     alias = '24b'
 
 
-_SUPPORTS_256 = frozenset(
-    [
-        'ANSICON',
-        'COLORTERM',
-        'ConEmuANSI',
-        'PYCHARM_HOSTED',
-        'TERM',
-        'TERMINAL_EMULATOR',
-        'TERM_PROGRAM',
-        'WT_SESSION',
-    ]
-)
-
-
-def is_vt_proc_enabled():
-    if os.name != 'nt' or os.environ.keys() & _SUPPORTS_256:
-        return True
-
+if os.name == 'nt':
     from ctypes import windll, wintypes
 
-    STD_OUTPUT_HANDLE = -11
-    ENABLE_VIRTUAL_TERMINAL_PROCESSING = 0x0004
-    kernel32 = windll.kernel32
-    kernel32.GetStdHandle.restype = wintypes.HANDLE
-    kernel32.GetConsoleMode.restype = kernel32.SetConsoleMode.restype = wintypes.BOOL
-    handle = kernel32.GetStdHandle(STD_OUTPUT_HANDLE)
-    if handle == -1:
-        return False
-    mode = wintypes.DWORD()
-    if not kernel32.GetConsoleMode(handle, byref(mode)):
-        return False
-    mode.value |= ENABLE_VIRTUAL_TERMINAL_PROCESSING
-    return kernel32.SetConsoleMode(handle, mode)
+    def _enable_vt_processing(handle: int):
+        ENABLE_VT_PROCESSING = 0x0004
+        k32 = windll.kernel32
+        k32.GetStdHandle.restype = wintypes.HANDLE
+        k32.GetConsoleMode.restype = k32.SetConsoleMode.restype = wintypes.BOOL
+        h = k32.GetStdHandle(handle)
+        if h == -1:
+            return False
+        mode = wintypes.DWORD()
+        if not k32.GetConsoleMode(h, byref(mode)):
+            return False
+        mode.value |= ENABLE_VT_PROCESSING
+        return bool(k32.SetConsoleMode(h, mode))
+
+    def is_vt_enabled():
+        if os.environ.keys() & {
+            'ANSICON',
+            'COLORTERM',
+            'ConEmuANSI',
+            'PYCHARM_HOSTED',
+            'TERM',
+            'TERMINAL_EMULATOR',
+            'TERM_PROGRAM',
+            'WT_SESSION',
+        }:
+            return True
+        ok = False
+        for fd, handle in [(sys.stdout, -11), (sys.stderr, -12)]:
+            if getattr(fd, "isatty", lambda: False)():
+                ok |= _enable_vt_processing(handle)
+        return ok
+
+else:
+
+    def is_vt_enabled():
+        return True
 
 
-DEFAULT_ANSI = ansicolor8Bit if is_vt_proc_enabled() else ansicolor4Bit
+DEFAULT_ANSI = ansicolor8Bit if is_vt_enabled() else ansicolor4Bit
 
 AnsiColorFormat: TypeAlias = ansicolor4Bit | ansicolor8Bit | ansicolor24Bit
 AnsiColorType: TypeAlias = type[AnsiColorFormat]
 AnsiColorParam: TypeAlias = AnsiColorAlias | AnsiColorType
 _AnsiColor_co = TypeVar('_AnsiColor_co', bound=colorbytes, covariant=True)
-_ANSI_COLOR_TYPES = cast(frozenset[AnsiColorType], frozenset(colorbytes.__subclasses__()))
+_ANSI_COLOR_TYPES = cast(
+    frozenset[AnsiColorType], frozenset(colorbytes.__subclasses__())
+)
 _ANSI_FORMAT_MAP = {k: x for x in _ANSI_COLOR_TYPES for k in [x, x.alias]}
 
 
-@lru_cache
+@lru_cache(maxsize=len(_ANSI_COLOR_TYPES))
 def _is_ansi_type(typ: type):
     try:
         return typ in _ANSI_COLOR_TYPES
@@ -403,11 +409,43 @@ def _is_ansi_type(typ: type):
         return False
 
 
-@lru_cache(maxsize=None)
-def sgr_re_pattern():
+@lru_cache(maxsize=len(_ANSI_FORMAT_MAP))
+def get_ansi_type(typ):
+    try:
+        return _ANSI_FORMAT_MAP[typ]
+    except (TypeError, KeyError) as e:
+        if isinstance(typ, str):
+            err = ValueError(f"invalid ANSI color format alias: {e!r}")
+        else:
+            from .._typing import unionize
+
+            repr_getter = lambda t: (t if isinstance(t, type) else type(t))
+            msg = (
+                "Expected {.__name__!r} or {}, got {.__name__!r} object instead".format(
+                    str,
+                    type[unionize(set(map(repr_getter, _ANSI_FORMAT_MAP.values())))],
+                    repr_getter(typ),
+                )
+            )
+            err = TypeError(msg)
+        err.__cause__ = e.__cause__
+        raise err
+
+
+def set_default_ansi(typ):
+    """Sets the global `DEFAULT_ANSI` variable to the specified ANSI color format"""
+    if valid_typ := get_ansi_type(typ):
+        global DEFAULT_ANSI
+        DEFAULT_ANSI = valid_typ
+
+
+@lru_cache(maxsize=1)
+def sgr_pattern():
     uint8_re = r"(?:25[0-5]|2[0-4]\d|1\d{2}|[1-9]\d|\d)"
     ansicolor_re = f"[3-4]8;(?:2(?:;{uint8_re}){{3}}|5;{uint8_re})"
-    sgr_param_re = rf"(?:{ansicolor_re}|10[0-7]|9[0-7]|6[0-3]|5[02-5]|2[0-68-9]|[13-4]\d|\d)"
+    sgr_param_re = (
+        rf"(?:{ansicolor_re}|10[0-7]|9[0-7]|6[0-3]|5[02-5]|2[0-68-9]|[13-4]\d|\d)"
+    )
 
     return re.compile(rf"\x1b\[(?:{sgr_param_re}(?:;{sgr_param_re})*)?m")
 
@@ -415,7 +453,7 @@ def sgr_re_pattern():
 def _split_ansi_escape(__s: str) -> list[tuple['SgrSequence', str]] | None:
     out = []
     i = 0
-    for m in sgr_re_pattern().finditer(__s):
+    for m in sgr_pattern().finditer(__s):
         text = __s[i : (j := m.start())]
         if i != j:
             out.append(text)
@@ -436,7 +474,10 @@ def _split_ansi_escape(__s: str) -> list[tuple['SgrSequence', str]] | None:
     out = tmp
     if out and len(out) % 2 != 0:
         out.append({SgrSequence: str, str: SgrSequence}[type(out[-1])]())
-    return [(a, b) if isinstance(a, SgrSequence) else (b, a) for a, b in zip(out[::2], out[1::2])]
+    return [
+        (a, b) if isinstance(a, SgrSequence) else (b, a)
+        for a, b in zip(out[::2], out[1::2])
+    ]
 
 
 def _unwrap_ansi_escape(__b: bytes | bytearray):
@@ -447,27 +488,6 @@ def _concat_ansi_escape(__it: Iterable[bytes | bytearray]):
     return b'\x1b[%sm' % b';'.join(__it)
 
 
-@lru_cache
-def get_ansi_type(typ):
-    try:
-        return _ANSI_FORMAT_MAP[typ]
-    except (TypeError, KeyError) as e:
-        if isinstance(typ, str):
-            err = ValueError(f"invalid ANSI color format alias: {e!r}")
-        else:
-            from .._typing import unionize
-
-            repr_getter = lambda t: (t if isinstance(t, type) else type(t))
-            msg = "Expected {.__name__!r} or {}, got {.__name__!r} object instead".format(
-                str,
-                type[unionize(set(map(repr_getter, _ANSI_FORMAT_MAP.values())))],
-                repr_getter(typ),
-            )
-            err = TypeError(msg)
-        err.__cause__ = e.__cause__
-        raise err
-
-
 def rgb2ansi_escape(fmt, mode, rgb):
     fmt = get_ansi_type(fmt)
     if len(rgb) != 3:
@@ -597,10 +617,17 @@ def _get_sgr_nums(__x: bytes) -> list[int]:
     """
     if __x.isdigit():
         return [int(__x)]
-    __x = __x.removeprefix(CSI)[: idx if ~(idx := __x.find(0x6D)) else None].removesuffix(b'm')
+    __x = __x.removeprefix(CSI)[
+        : idx if ~(idx := __x.find(0x6D)) else None
+    ].removesuffix(b'm')
     length = len(__x)
     mask_indices = enumerate(
-        map(bool, int.to_bytes(~int.from_bytes(b';' * length) & int.from_bytes(__x), length=length))
+        map(
+            bool,
+            int.to_bytes(
+                ~int.from_bytes(b';' * length) & int.from_bytes(__x), length=length
+            ),
+        )
     )
     res = []
     buf = bytearray()
@@ -624,8 +651,9 @@ def _iter_normalized_sgr[_T: (
     Buffer,
     SupportsInt,
 )](__iter: bytes | bytearray | Iterable[_T]) -> Iterator[int | AnsiColorFormat]:
-    __iter: ...
-    for elt in __iter.split(b';') if isinstance(__iter, (bytes, bytearray)) else __iter:
+    if isinstance(__iter, (bytes, bytearray)):
+        __iter = __iter.split(b';')
+    for elt in __iter:
         match elt:
             case (colorbytes() as cb) | SgrParamBuffer(colorbytes() as cb):
                 yield cb
@@ -645,7 +673,9 @@ def _iter_normalized_sgr[_T: (
                 )
 
 
-def _co_yield_colorbytes(__iter: Iterator[int]) -> Generator[bytes | AnsiColorFormat, int, None]:
+def _co_yield_colorbytes(
+    __iter: Iterator[int],
+) -> Generator[bytes | AnsiColorFormat, int, None]:
     d: dict[int, ColorDictKeys] = {38: 'fg', 48: 'bg'}
     obj = b''
     while True:
@@ -737,7 +767,8 @@ class SgrSequence(MutableSequence[SgrParamBuffer]):
     def ansi_type(self):
         if self.is_color():
             typ, _ = max(
-                Counter(type(x._value) for x in self if x.is_color()).items(), key=lambda x: x[1]
+                Counter(type(x._value) for x in self if x.is_color()).items(),
+                key=lambda x: x[1],
             )
             return typ
 
@@ -751,7 +782,8 @@ class SgrSequence(MutableSequence[SgrParamBuffer]):
                 )
             case ColorStr():
                 return color_chain._from_masks_unchecked(
-                    [(self, ''), (other._sgr, other.base_str)], self.ansi_type() or DEFAULT_ANSI
+                    [(self, ''), (other._sgr, other.base_str)],
+                    self.ansi_type() or DEFAULT_ANSI,
                 )
             case str():
                 return ColorStr(f"{self}{other}")
@@ -831,7 +863,9 @@ class SgrSequence(MutableSequence[SgrParamBuffer]):
                 elts[SgrParamBuffer(elt)] = None
 
             self._sgr_params = list(elts)
-            self._rgb_dict = {k: v for xs in colors.values() for k, v in xs._rgb_dict.items()}
+            self._rgb_dict = {
+                k: v for xs in colors.values() for k, v in xs._rgb_dict.items()
+            }
 
     def __iter__(self):
         return iter(self._sgr_params)
@@ -850,7 +884,9 @@ class SgrSequence(MutableSequence[SgrParamBuffer]):
             __value: ...
             xs = list(_iter_sgr(__value))
             if len(xs) != 1:
-                err = ValueError(f"parsed {len(xs)} sgr parameters, expected only 1: {xs!r}")
+                err = ValueError(
+                    f"parsed {len(xs)} sgr parameters, expected only 1: {xs!r}"
+                )
                 raise err
             self._sgr_params[__index] = SgrParamBuffer(xs.pop())
         self._update_colors()
@@ -911,44 +947,43 @@ _END_RESET_PATTERN = re.compile(r"\x1b\[0?m$")
 _unset: Any = object()
 
 
-def _make_colorstr[_T: ColorStr](cls: type[_T], obj=_unset, *args, **kwargs) -> _T:
-    sgr = SgrSequence()
-    fg = kwargs.pop('fg', _unset)
-    bg = kwargs.pop('bg', _unset)
-    ansi_type = kwargs.pop('ansi_type', _unset)
-    reset = kwargs.pop('reset', _unset)
-    if kwargs:
-        if not kwargs.keys() <= {'encoding', 'errors'}:
-            raise ValueError(
-                f"unexpected keyword arguments: {(kwargs.keys() - {'encoding', 'errors'})}"
-            )
+def _colorstr[_T: ColorStr](
+    cls: type[_T],
+    obj=_unset,
+    /,
+    fg=None,
+    bg=None,
+    *,
+    encoding=_unset,
+    errors=_unset,
+    ansi_type=_unset,
+    reset=True,
+) -> _T:
+    if buf_kwargs := {
+        k: v
+        for k, v in locals().items()
+        if k in {"encoding", "errors"} and v is not _unset
+    }:
         if not isinstance(obj, Buffer):
-            raise ValueError(
-                "expected buffer or bytes-like object, "
-                f"got {type(obj).__name__!r} object instead"
-            )
-        encoding = kwargs.pop('encoding', 'utf-8')
-        errors = kwargs.pop('errors', 'strict')
-        if isinstance(obj, (bytes, bytearray)):
-            obj = obj.decode(encoding, errors)
-        else:
-            obj = bytes(obj).decode(encoding, errors)
+            raise ValueError(f"unexpected keyword arguments: {set(buf_kwargs)}")
+        elif not isinstance(obj, (bytes, bytearray)):
+            obj = bytes(obj)
+        obj = obj.decode(**buf_kwargs)
+    sgr = SgrSequence()
+
     if obj is not _unset:
         if isinstance(obj, str):
             base_str = str(obj)
-            while m := sgr_re_pattern().match(base_str):
-                sgr.extend(m[0].removeprefix('\x1b[').removesuffix('m').encode())
+            sgr_match = sgr_pattern().match
+            while m := sgr_match(base_str):
+                sgr.extend(m[0].removeprefix("\x1b[").removesuffix('m').encode())
                 base_str = base_str[m.end() :]
             base_str = _END_RESET_PATTERN.sub('', base_str)
         else:
             base_str = str(obj)
     else:
         base_str = ''
-    if '\x1b[' in base_str:
-        raise ValueError
-    if reset is _unset:
-        reset = True
-    elif type(reset) is not bool:
+    if type(reset) is not bool:
         reset = bool(reset)
     if ansi_type is not _unset:
         ansi_type = get_ansi_type(ansi_type)
@@ -960,34 +995,8 @@ def _make_colorstr[_T: ColorStr](cls: type[_T], obj=_unset, *args, **kwargs) ->
             key=lambda x: x[1],
         )[0]
     try:
-        if fg is bg is _unset:
-            match args:
-                case []:
-                    fg = bg = None
-                case [_ as fg]:
-                    bg = None
-                case [_ as fg, _ as bg]:
-                    pass
-                case _:
-                    raise ValueError
-        elif fg is _unset:
-            match args:
-                case []:
-                    fg = None
-                case [_ as fg]:
-                    pass
-                case _:
-                    raise ValueError
-        elif bg is _unset:
-            match args:
-                case []:
-                    bg = None
-                case [_ as bg]:
-                    pass
-                case _:
-                    raise ValueError
-        for k, v in dict.items({'fg': fg, 'bg': bg}):
-            if v is None:
+        for k, v in locals().items():
+            if k not in {"fg", "bg"} or v is None:
                 continue
             match v:
                 case Color(rgb=(_ as r, _ as g, _ as b)):
@@ -1001,31 +1010,35 @@ def _make_colorstr[_T: ColorStr](cls: type[_T], obj=_unset, *args, **kwargs) ->
                 case _:
                     raise TypeError(type(v))
             sgr.append(ansi_type.from_rgb((k, (r, g, b))).to_param_buffer())
-    except (ValueError, TypeError) as e:
-        if isinstance(e, ValueError):
-            err = ValueError(
-                "ColorStr expected at most 2 positional arguments, " f"got {len(args)}"
-            )
-        else:
-            [typ] = e.args
-            err = TypeError(
-                "expected integer or vector of 3 integers, " f"got {typ.__name__!r} object instead"
-            )
+    except TypeError as e:
+        [typ] = e.args
+        err = TypeError(
+            "expected integer or vector of 3 integers, "
+            f"got {typ.__name__!r} object instead"
+        )
         err.__cause__ = e.__cause__
         raise err
-    inst: Any = str.__new__(cls, ''.join([str(sgr), base_str, SGR_RESET_S if reset else '']))
-    inst.__dict__ |= {'_sgr': sgr, '_base_str': base_str, '_ansi_type': ansi_type, '_reset': reset}
+    suffix = SGR_RESET_S if reset else ''
+    inst: Any = str.__new__(cls, f"{sgr}{base_str}{suffix}")
+    inst.__dict__ |= {
+        '_sgr': sgr,
+        '_base_str': base_str,
+        '_ansi_type': ansi_type,
+        '_reset': suffix,
+    }
     return inst
 
 
 class ColorStr(str):
     def _weak_var_update(self, **kwargs):
         if not kwargs.keys() <= {'base_str', 'sgr', 'reset'}:
-            raise ValueError(f'unexpected keys: {(kwargs.keys() - {'base_str', 'sgr', 'reset'})}')
+            raise ValueError(
+                f'unexpected keys: {(kwargs.keys() - {'base_str', 'sgr', 'reset'})}'
+            )
         sgr = kwargs.get('sgr', self._sgr)
         base_str = kwargs.get('base_str', self.base_str)
         suffix = SGR_RESET_S if kwargs.get('reset', self.reset) else ''
-        inst: Any = str.__new__(type(self), ''.join([str(sgr), base_str, suffix]))
+        inst = super().__new__(type(self), f"{sgr}{base_str}{suffix}")
         inst.__dict__ |= vars(self) | {f'_{k}': v for k, v in kwargs.items()}
         return inst
 
@@ -1033,7 +1046,7 @@ class ColorStr(str):
         r"""Returns a 3-tuple of parts of the string
         (sgr, base string, '\x1B[0m' or '')
         """
-        return str(self._sgr), self.base_str, SGR_RESET_S if self.reset else ''
+        return str(self._sgr), self.base_str, self._reset
 
     def as_ansi_type(self, __ansi_type):
         """Convert all ANSI colors in the `ColorStr` to a single ANSI type.
@@ -1054,9 +1067,7 @@ class ColorStr(str):
         if self.rgb_dict and ansi_type is not self.ansi_format:
             sgr = SgrSequence(self._sgr)
             sgr.rgb_dict = sgr._rgb_dict, ansi_type
-            inst = str.__new__(
-                type(self), ''.join([str(sgr), self.base_str, SGR_RESET_S if self.reset else ''])
-            )
+            inst = super().__new__(type(self), f"{sgr}{self.base_str}{self._reset}")
             inst.__dict__ |= vars(self) | {'_sgr': sgr, '_ansi_type': ansi_type}
             return inst
         return self
@@ -1122,7 +1133,9 @@ class ColorStr(str):
             ('Red text', '0x00FF00')
         """
         if not kwargs.keys() <= {'absolute', 'fg', 'bg'}:
-            raise ValueError(f"unexpected keywords: {(kwargs.keys() - {'absolute', 'fg', 'bg'})}")
+            raise ValueError(
+                f"unexpected keywords: {(kwargs.keys() - {'absolute', 'fg', 'bg'})}"
+            )
         if kwargs.pop('absolute', False):
             if not (args or kwargs):
                 return (
@@ -1167,14 +1180,18 @@ class ColorStr(str):
             if b'%d' % SgrParameter.DOUBLE_UNDERLINE in self._sgr:
                 return self
             elif b'%d' % SgrParameter.SINGLE_UNDERLINE in self._sgr:
-                return self.update_sgr(SgrParameter.SINGLE_UNDERLINE, SgrParameter.DOUBLE_UNDERLINE)
+                return self.update_sgr(
+                    SgrParameter.SINGLE_UNDERLINE, SgrParameter.DOUBLE_UNDERLINE
+                )
             else:
                 return self.update_sgr(SgrParameter.DOUBLE_UNDERLINE)
         else:
             if b'%d' % SgrParameter.SINGLE_UNDERLINE in self._sgr:
                 return self
             elif b'%d' % SgrParameter.DOUBLE_UNDERLINE in self._sgr:
-                return self.update_sgr(SgrParameter.DOUBLE_UNDERLINE, SgrParameter.SINGLE_UNDERLINE)
+                return self.update_sgr(
+                    SgrParameter.DOUBLE_UNDERLINE, SgrParameter.SINGLE_UNDERLINE
+                )
             else:
                 return self.update_sgr(SgrParameter.SINGLE_UNDERLINE)
 
@@ -1244,9 +1261,7 @@ class ColorStr(str):
                 sgr.remove(bx)
             else:
                 sgr.append(bx)
-        inst = super().__new__(
-            type(self), ''.join([str(sgr), self.base_str, SGR_RESET_S if self.reset else ''])
-        )
+        inst = super().__new__(type(self), f"{sgr}{self.base_str}{self._reset}")
         inst.__dict__ |= vars(self) | {
             '_sgr': sgr,
             '_ansi_type': sgr.ansi_type() or self.ansi_format,
@@ -1321,10 +1336,12 @@ class ColorStr(str):
 
     def join(self, __iterable):
         return self._weak_var_update(
-            base_str=self.base_str.join(getattr(elt, 'base_str', elt) for elt in __iterable)
+            base_str=self.base_str.join(
+                getattr(elt, 'base_str', elt) for elt in __iterable
+            )
         )
 
-    def ljust(self, __width, __fillchar=" "):
+    def ljust(self, __width, __fillchar=' '):
         return self._weak_var_update(base_str=self.base_str.ljust(__width, __fillchar))
 
     def lower(self):
@@ -1334,7 +1351,9 @@ class ColorStr(str):
         return self._weak_var_update(base_str=self.base_str.lstrip(__chars))
 
     def partition(self, __sep):
-        lhs, sep, rhs = (self._weak_var_update(base_str=s) for s in self.base_str.partition(__sep))
+        lhs, sep, rhs = (
+            self._weak_var_update(base_str=s) for s in self.base_str.partition(__sep)
+        )
         return lhs, sep, rhs
 
     def removeprefix(self, __prefix):
@@ -1344,7 +1363,9 @@ class ColorStr(str):
         return self._weak_var_update(base_str=self.base_str.removesuffix(__prefix))
 
     def replace(self, __old, __new, __count=-1):
-        return self._weak_var_update(base_str=self.base_str.replace(__old, __new, __count))
+        return self._weak_var_update(
+            base_str=self.base_str.replace(__old, __new, __count)
+        )
 
     def rfind(self, __sub, *args):
         return self.base_str.rfind(__sub, *args)
@@ -1359,7 +1380,9 @@ class ColorStr(str):
         return self._weak_var_update(base_str=self.base_str.rstrip(__chars))
 
     def rpartition(self, __sep):
-        lhs, sep, rhs = (self._weak_var_update(base_str=s) for s in self.base_str.rpartition(__sep))
+        lhs, sep, rhs = (
+            self._weak_var_update(base_str=s) for s in self.base_str.rpartition(__sep)
+        )
         return lhs, sep, rhs
 
     def rsplit(self, sep=None, maxsplit=-1):
@@ -1376,7 +1399,8 @@ class ColorStr(str):
 
     def splitlines(self, keepends=False):
         return [
-            self._weak_var_update(base_str=s) for s in self.base_str.splitlines(keepends=keepends)
+            self._weak_var_update(base_str=s)
+            for s in self.base_str.splitlines(keepends=keepends)
         ]
 
     def startswith(self, __prefix, *args):
@@ -1465,7 +1489,7 @@ class ColorStr(str):
         return self._weak_var_update(base_str=self.base_str * __value)
 
     def __new__(cls, obj=_unset, *args, **kwargs):
-        return _make_colorstr(cls, obj, *args, **kwargs)
+        return _colorstr(cls, obj, *args, **kwargs)
 
     def __repr__(self):
         return f'{type(self).__name__}({str(self)!r})'
@@ -1476,11 +1500,15 @@ class ColorStr(str):
         k: L['fg', 'bg']
         if isinstance(other, type(self)):
             xor_dict = {
-                k: int2rgb(Color.from_rgb(self.rgb_dict[k]) ^ Color.from_rgb(other.rgb_dict[k]))
+                k: int2rgb(
+                    Color.from_rgb(self.rgb_dict[k]) ^ Color.from_rgb(other.rgb_dict[k])
+                )
                 for k in self.rgb_dict.keys() & other.rgb_dict
             }
         elif isinstance(other, int):
-            xor_dict = {k: int2rgb(Color.from_rgb(v) ^ other) for k, v in self.rgb_dict.items()}
+            xor_dict = {
+                k: int2rgb(Color.from_rgb(v) ^ other) for k, v in self.rgb_dict.items()
+            }
         else:
             return NotImplemented
         if not xor_dict:
@@ -1516,7 +1544,7 @@ class ColorStr(str):
 
     @property
     def reset(self):
-        return getattr(self, '_reset')
+        return bool(self._reset)
 
     @property
     def rgb_dict(self):
@@ -1596,7 +1624,10 @@ class color_chain:
         elif isinstance(other, str):
             if len(self._masks) > 0:
                 return self._from_masks_unchecked(
-                    [*self.masks[:-1], (self._masks[-1][0], self._masks[-1][1] + other)],
+                    [
+                        *self.masks[:-1],
+                        (self._masks[-1][0], self._masks[-1][1] + other),
+                    ],
                     ansi_type=self._ansi_type,
                 )
             return self._from_masks_unchecked(
@@ -1615,7 +1646,9 @@ class color_chain:
         if not kwargs.keys() <= {'fg', 'bg'}:
             raise ValueError
         sgr = SgrSequence(__sgr)
-        sgr.rgb_dict = {k: v for k, v in kwargs.items() if v is not None}, self._ansi_type
+        sgr.rgb_dict = {
+            k: v for k, v in kwargs.items() if v is not None
+        }, self._ansi_type
         self._masks = [(sgr, '')]
 
     def __radd__(self, other):
